#include <hidef.h>					// common defines and macros 
#include "derivative.h"				// derivative-specific definitions
#include "sci_hc12.h"				// sci routines

#define LED1	PTT_PTT4
#define LED2	PTT_PTT5
#define LED3	PTT_PTT6
#define LED4	PTT_PTT7

#define SW1		0x10
#define SW2		0x20
#define SW3		0x40
#define SW4		0x80

#define nON		0
#define nOFF	1

#define BLINK	0x1000


/**********************************************************
*	CPMU_PEE_8MHz
*
*	Setup clock module for PLL Engaged using External XTAL
*	For 8MHz XTAL - 
*	VCOCLK - 64MHz, Core Clk - 16MHz, Bus Clk - 8MHz
**********************************************************/
void CPMU_PEE_8MHz(void){

	CPMUSYNR = 0x01;					// fVCO = 32MHz
	CPMUREFDIV = 0x80;				// OSC input is 8MHz
	CPMUPOSTDIV = 0x01;				// core clk - 16MHz, bus clk - 8MHz
	
	CPMUOSC_OSCE = 1;					// enable ext OSC
	while(!CPMUFLG_UPOSC || !CPMUFLG_LOCK);
											// wait for ext osc to stabilize and pll to lock
	CPMUFLG = 0xFF;					// clear CMPMU int flags - not needed but good practice
}


/**********************************************************
*	ATD_EN
*
*	Configure ATD to sample CH0.  Write Channel Select Code
*	bits C[D:A] to start conversion sequence
**********************************************************/
void ATD_EN(void){

	ATDCTL1_SRES = 0;					// 8 bit results
	ATDCTL3_DJM = 1;					// right justified data
	ATDCTL4_PRS = 0;					// bus clk div 2, 4 clks per sample
	ATDSTAT0_SCF = 1;					// clear flag
}


void main(void) {
	byte n, atd_val, sled;
	word p = 0, delay = 0;
	byte m[] = "Welcome to Axiom Manufcturing \n";
	
	CPMUCOP_CR = 0;					// disable COP
//	EnableInterrupts;
	
	CPMU_PEE_8MHz();					// enable ext osc
	ATD_EN();							// enable ATD

	PTT = 0xF0;							//	init PTT[7:4] output
	DDRT = 0xF0;						//	PTT[7:4] output others input

	ATDDIEN = 0x00F0;					// enable sw input on PAD[7:4]   
	PER0AD = 0x80;						// enable PU on PAD15 to enable COM
	PER1AD = 0xF0;						// enable PBSW pulls
	PPS1AD = 0x00;						// pull-ups applied

	PTM = 0x02;							// init PORT M
	DDRM = 0x03;						// PTM[1:0] output
		
	ensci();								// enable serial routines

	for(n=0;n<30;n++){
		cputs(m);
	}

	for(;;) {
		
		delay++;							// increment delay counter
		if(delay == BLINK){			// if terminal count
			PTM_PTM0 ^= 1;				// toggle PTM0
			PTM_PTM1 ^= 1;				// toggle PTM1
			delay = 0;					// reset counter
		}

		echo_com();						// echo keybd data

		ATDCTL5_Cx = 0;				// start conversion on CH0
		while(!(ATDSTAT0_SCF));		// wait for conversion complete

		atd_val = (byte) ATDDR0;				// get converted value
		if(atd_val <= 0x3C) 
			sled = 0;					// select led state 0, all leds off
		if((atd_val > 0x3C) && (atd_val <= 0x78))
			sled = 1;					// select led state 1, led1 on
		if((atd_val > 0x78) && (atd_val <= 0xB4))
			sled = 2;					// select led state 2, led1-2 on
		if((atd_val > 0xB4) && (atd_val <= 0xF0))
			sled = 3;					// select led state 3, led1-3 on
		if(atd_val > 0xF0)
			sled = 4;					// select led state 4, all leds on
		
		switch(sled){
			case 4:
				LED4 = nON;				// LED4 ON
				LED3 = nON;				// LED3 ON
				LED2 = nON;				// LED2 ON
				LED1 = nON;				// LED1 ON
				break;
			case 3:
				LED4 = nOFF;			// LED4 ON
				LED3 = nON;				// LED3 ON
				LED2 = nON;				// LED2 ON
				LED1 = nON;				// LED1 ON
				break;
			case 2:
				LED4 = nOFF;			// LED4 ON
				LED3 = nOFF;			// LED3 ON
				LED2 = nON;				// LED2 ON
				LED1 = nON;				// LED1 ON
				break;
			case 1:
				LED4 = nOFF;			// LED4 ON
				LED3 = nOFF;			// LED3 ON
				LED2 = nOFF;			// LED2 ON
				LED1 = nON;				// LED1 ON
				break;
			default:
				LED4 = nOFF;			// LED4 ON
				LED3 = nOFF;			// LED3 ON
				LED2 = nOFF;			// LED2 ON
				LED1 = nOFF;			// LED1 ON
				break;
		}

		switch(PT1AD) {				// get switch interrupt status
			case 0xEF:{					// SW1 pressed
				LED1 ^= 1;				// toggle LED1
				while((PT1AD & SW1) == 0);	// wait for PBSW release
//				PIF1AD &= SW1;			// clr int flag
				break;
			}
			case 0xDF:{					// SW2 pressed
				LED2 ^= 1;				// toggle LED2
				while((PT1AD & SW2) == 0);	// wait for PBSW release
//				PIF1AD &= SW2;			// clr int flag
				break;
			}
			case 0xBF:{					// SW1 pressed
				LED3 ^= 1;				// toggle LED3
				while((PT1AD & SW3) == 0);	// wait for PBSW release
//				PIF1AD &= SW3;			// clr int flag
				break;
			}
			case 0x7F:{					// SW1 pressed
				LED4 ^= 1;				// toggle LED4
				while((PT1AD & SW4) == 0);	// wait for PBSW release
//				PIF1AD &= SW4;			// clr int flag
				break;
			}
			default:
				break;
		}
	}
}
